import React from 'react';
import {
    Container,
    Segment,
    Form,
    Input,
    Button,
    Checkbox,
    Grid,
    Menu,
    List
} from 'semantic-ui-react';
import ConditionField from './Condition';
import ActionSelect from './ActionSelect';
import ActionList from './ActionList';

const stateDefault = ()=>({
    groups: {},
    idx: 0,
    active: 0,
    actions: []
})

class ActionLinkAdd extends React.Component {
    state = {
        ...stateDefault()
    }

    changeState = (tag, value) => {
        if(tag == 'active'){
            this.setState({
                active: value?1:0
            })
        }
    }

    addNewGroup = (data, cb = null) => {
        let devs = [];
        let {groups} = this.state
        if(data.id1.type == 'ln') devs.push(data.id1.dev)
        if(data.id2.type == 'ln') devs.push(data.id2.dev)
        
        data.id1 = {...data.id1, ...groups[data.id1.dev]}
        data.id2 = {...data.id2, ...groups[data.id2.dev]}
        delete data.id1.dev;
        delete data.id2.dev;

        for(let i in devs){
            if(devs[i] in groups) delete groups[devs[i]];
        }

        let idx = this.state.idx + 1;
        groups[`unit${idx}`] = data;

        this.setState({
            groups,
            idx
        }, ()=>{
            if(cb && typeof cb == 'function') cb();
        })
    }

    addNewAction = (data, cb=null) => {
        this.setState({
            actions: [...this.state.actions, data]
        }, ()=>{
            if(cb && typeof cb == 'function') cb();
        })
    }

    removeAction = (idx) => {
        let {actions} = this.state;
        actions.splice(idx, 1);
        this.setState({
            actions
        })
    }

    render() {
        let {i18n, showDialog, toggleLoading} = this.props;
        return (
            <Container>
                <Menu>
                    <Menu.Menu position="right">
                        <Menu.Item content="ShowTree" onClick={()=>{ console.log(this.state) }}/>
                        <Menu.Item content="Save" onClick={()=>{}}/>
                    </Menu.Menu>
                </Menu>
                <Form as={Segment}>
                    <Form.Field>
                        <Checkbox label="啟用連動" checked={this.state.active == 1} onChange={(e,d)=>{this.changeState('active', d.checked)}} />
                    </Form.Field>
                    <Form.Field>
                        <label>建立條件群組</label>
                        <ConditionField i18n={i18n} 
                            showDialog={showDialog} 
                            toggleLoading={toggleLoading} 
                            groups={this.state.groups}
                            addNewGroup={this.addNewGroup} />
                    </Form.Field>
                    <Form.Field>
                        <label>加入動作</label>
                        <ActionSelect i18n={i18n}
                            showDialog={showDialog} 
                            toggleLoading={toggleLoading}
                            addNewAction={this.addNewAction}  />
                    </Form.Field>
                    <Form.Field>
                        <label>已選擇動作</label>
                        <ActionList i18n={i18n} list={this.state.actions} removeAction={this.removeAction} />
                    </Form.Field>
                </Form>
            </Container>
        )
    }
}

export default ActionLinkAdd;